==> shardingsphere-3.0.0.M1.tar.bz2: shardingsphere-3.0.0.M1/sharding-core/src/test/java/io/shardingsphere/core/rule/MasterSlaveRuleTest.java <==
/*
 * Copyright 2016-2018 shardingsphere.io.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * </p>
 */

package io.shardingsphere.core.rule;

import io.shardingsphere.core.api.config.MasterSlaveRuleConfiguration;
import org.junit.Test;

import java.util.Collections;

public final class MasterSlaveRuleTest {
    
    @Test(expected = NullPointerException.class)
    public void assertNewMasterSlaveRuleFailure() {
        MasterSlaveRuleConfiguration masterSlaveRuleConfig = new MasterSlaveRuleConfiguration("", "", null, null);
        new MasterSlaveRule(masterSlaveRuleConfig);
    }
    
    @Test(expected = IllegalStateException.class)
    public void assertNewMasterSlaveRuleWithEmptySlaveDataSourceNames() {
        MasterSlaveRuleConfiguration masterSlaveRuleConfig = new MasterSlaveRuleConfiguration("", "", Collections.<String>emptyList(), null);
        new MasterSlaveRule(masterSlaveRuleConfig);
    }
    
    @Test
    public void assertNewMasterSlaveRuleSuccess() {
        MasterSlaveRuleConfiguration masterSlaveRuleConfig = new MasterSlaveRuleConfiguration("master_slave", "master0", Collections.singletonList("slave0"), null);
        new MasterSlaveRule(masterSlaveRuleConfig);
    }
}

==> shardingsphere-3.1.0.M1.tar.bz2: shardingsphere-3.1.0.M1/sharding-core/src/test/java/io/shardingsphere/core/rule/MasterSlaveRuleTest.java <==
/*
 * Copyright 2016-2018 shardingsphere.io.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * </p>
 */

package io.shardingsphere.core.rule;

import io.shardingsphere.api.config.rule.MasterSlaveRuleConfiguration;
import org.junit.Test;

import java.util.Collections;

public final class MasterSlaveRuleTest {
    
    @Test(expected = NullPointerException.class)
    public void assertNewMasterSlaveRuleFailure() {
        MasterSlaveRuleConfiguration masterSlaveRuleConfig = new MasterSlaveRuleConfiguration("", "", null, null);
        new MasterSlaveRule(masterSlaveRuleConfig);
    }
    
    @Test(expected = IllegalStateException.class)
    public void assertNewMasterSlaveRuleWithEmptySlaveDataSourceNames() {
        MasterSlaveRuleConfiguration masterSlaveRuleConfig = new MasterSlaveRuleConfiguration("", "", Collections.<String>emptyList(), null);
        new MasterSlaveRule(masterSlaveRuleConfig);
    }
    
    @Test
    public void assertNewMasterSlaveRuleSuccess() {
        MasterSlaveRuleConfiguration masterSlaveRuleConfig = new MasterSlaveRuleConfiguration("master_slave", "master0", Collections.singletonList("slave0"), null);
        new MasterSlaveRule(masterSlaveRuleConfig);
    }
}
